@@ -190,8 +190,12 @@ class MiniRpaManager(MiniRpaFunction):
                     sap_automation.select_se16_layout_before_download_excel(layout_name, shortcut_list)
                 elif function_name == 'click_button':
                     sap_automation.click_button(sap_operation_dict['button_title'])
+                elif function_name == 'click_button_by_mouse':
+                    sap_automation.click_button_by_mouse(sap_operation_dict['button_title'])
                 elif function_name == 'click_radio_checkbox':
                     sap_automation.click_radio_checkbox(sap_operation_dict['radio_checkbox_title'])
+                elif function_name=='click_radio_checkbox_by_mouse':
+                    sap_automation.click_radio_checkbox_by_mouse(sap_operation_dict['radio_checkbox_title'])
                 elif function_name == 'input_reporting_period':
                     sap_automation.input_reporting_period(sap_operation_dict['reporting_period_name'], sap_operation_dict['reporting_start_date'],
                                                           sap_operation_dict['reporting_end_date'])
@@ -242,6 +246,8 @@ class MiniRpaManager(MiniRpaFunction):
                     sap_automation.process_sm35_session(sap_operation_dict['session_name'], sap_operation_dict['session_created_by'])
                 elif function_name == 'check_sm35_session_status':
                     sap_automation.check_sm35_session_status(sap_operation_dict['session_name'], sap_operation_dict['session_created_by'])
+                elif function_name == 'wait_in_seconds':
+                    sap_automation.wait_in_seconds(int(sap_operation_dict['wait_seconds']))
 
             if sap_automation:
                 sap_automation.web_rpa.quit_browser()
