@@ -247,8 +247,30 @@ class MiniRpaSapAutomation:
         # except:
         #     self.web_rpa.click_or_input_by_css_selector(f"span[aria-label='{radio_checkbox_title}']", 'click')
 
+    def click_radio_checkbox_by_mouse(self, radio_checkbox_title):
+        """ This function is used to click radio or checkbox in SE16.
+
+        Args:
+            radio_checkbox_title(str): This is the title of radio or checkbox
+        """
+        wait_time = 60
+        while wait_time > 0:
+            try:
+                self.web_rpa.browser.find_element(By.CSS_SELECTOR, f"span[title='{radio_checkbox_title}']")
+                self.web_rpa.move_to_and_click_element(f"span[title='{radio_checkbox_title}']")
+                return
+            except NoSuchElementException:
+                try:
+                    self.web_rpa.browser.find_element(By.CSS_SELECTOR, f"span[aria-label='{radio_checkbox_title}']")
+                    self.web_rpa.move_to_and_click_element(f"span[aria-label='{radio_checkbox_title}']")
+                    return
+                except NoSuchElementException:
+                    sleep(1)
+                    wait_time -= 1
+        raise Exception(f"Cannot find radio or checkbox with title: {radio_checkbox_title}")
+
     def click_button(self, button_title):
-        """ This function is used to click button in SE16.
+        """ This function is used to click button
 
         Args:
             button_title(str): This is the title of button
@@ -256,6 +278,15 @@ class MiniRpaSapAutomation:
         self.web_rpa.click_or_input_by_css_selector(f"div[title='{button_title}']", 'click')
         sleep(1)
 
+    def click_button_by_mouse(self, button_title):
+        """ This function is used to click button by mouse.
+
+        Args:
+            button_title(str): This is the title of button
+        """
+        self.web_rpa.move_to_and_click_element(f"div[title='{button_title}']")
+        sleep(1)
+
     def click_execute_button(self):
         """ This function is used to click execute button in SE16.
         """
@@ -344,6 +375,7 @@ class MiniRpaSapAutomation:
         self.web_rpa.activate_context_click(column_css_selector)
         sleep(2)
         self.web_rpa.click_or_input_by_css_selector(f"tr[aria-label^='{context_menu_item_name}']", 'click')
+        # self.web_rpa.move_to_and_click_element(f"tr[aria-label^='{context_menu_item_name}']")
         sleep(1)
 
     def download_excel_by_context_click(self, column_name, context_menu_item_name, file_name):
@@ -964,3 +996,12 @@ class MiniRpaSapAutomation:
                     break
         else:
             print(f'No SM35 session found for {session_name} {session_created_by}!')
+
+    def wait_in_seconds(self, wait_seconds):
+        """ This function is used to wait for a specific number of seconds.
+
+        Args:
+            wait_seconds(int): The number of seconds to wait.
+        """
+        sleep(wait_seconds)
+        self.web_rpa.wait_invisibility_of_loading_window()
